<template>
    <el-form
        label-width="160px"
        :model="form"
        :disabled="disabled"
        style="position: relative;"
        size="small"
    >
        <el-card :body-style="{ height: '350px', overflow: 'auto'}">
            <el-form-item label="部门负责人">
                <el-select
                    v-model="form.departmentHeadId" 
                    placeholder="请选择"
                    style="width: 100%"
                >
                    <el-option
                        v-for="(item, index) in userList"
                        :key="index"
                        :label="item.name"
                        :value="item.id"
                    ></el-option>
                </el-select>
            </el-form-item>
            <el-form-item label="被监督人">
                <el-select
                    v-model="form.supervisedPersonId" 
                    placeholder="请选择"
                    style="width: 100%"
                >
                    <el-option
                        v-for="(item, index) in userList"
                        :key="index"
                        :label="item.name"
                        :value="item.id"
                    ></el-option>
                </el-select>
            </el-form-item>
            <el-form-item label="不符合工作发现途径">
                <el-checkbox-group 
                    v-model="form.discoveryApproach"
                >
                    <el-checkbox
                        v-for="(item, index) in checkbox"
                        :key="index"
                        :label="item.value" 
                        name="type"
                    >{{ item.label }}
                    </el-checkbox>
                </el-checkbox-group>
            </el-form-item>
            <el-form-item label="不符合工作的详细记录">
                <el-input
                    v-model="form.notConformDetails"
                    type="textarea"
                    :rows="2"
                    placeholder="请输入内容"
                ></el-input>
            </el-form-item>
            <el-form-item label="不符合的依据及条款号">
                <el-input 
                    v-model="form.nonConformityClause"
                    type="textarea"
                    :rows="2"
                    placeholder="请输入内容"
                ></el-input>
            </el-form-item>
        </el-card>
        <el-form-item label-width="0">
            <div style=" display: flex; width: 100%; justify-content: space-between; margin-top: 15px;">
                <div>
                    操作人：{{ currentResponsible }}
                </div>
                <div v-if="step == 0 || step == 1">
                    <el-button v-if="step == 1" :disabled="false" @click="cancel">驳回</el-button>
                    <el-button :disabled="false" @click="save">保存</el-button>
                    <el-button type="primary" @click="onSubmit" :disabled="false">提交</el-button>
                </div>
            </div>
        </el-form-item>
    </el-form>
</template>
<script>

export default {
    props: {
        currentResponsible: {
            type: String,
            default: ''
        },
        disabled: {
            type: Boolean,
            default: false
        },
        userList: {
            type: Array,
            default: () => {
                return []
            }
        },
        step: {
            type: Number,
            default: 0
        },
        condiForm: {
            type: Object,
            default: () => {
                return {}
            }
        }
    },
    computed: {
        form: {
            get() {
                return this.condiForm
            },
            set(val) {
                this.$emit('update:condiForm', val)
            }
        }
    },
    data() {
        return {
            checkbox: [
                {
                    label: '管理评审',
                    value: 0
                }, {
                    label: '内部审核',
                    value: 1
                }, {
                    label: '检测过程控制',
                    value: 2
                }, {
                    label: '内部质量控制',
                    value: 3
                }, {
                    label: '内部监督',
                    value: 4
                }, {
                    label: '外部评审/检查',
                    value: 5
                }, {
                    label: '顾客投诉/意见反馈',
                    value: 6
                }, {
                    label: '其他',
                    value: 7
                }
            ],
        }
    },
    methods: {
        onSubmit() {
            this.$emit('nextStep', 'submit')
        },
        save() {
            this.$emit('nextStep', 'save')
        },
        cancel() {
            this.$emit('cancel', 'cancel')
        }
    }
}
</script>